@@ -1,9 +1,29 @@
-
 /*
 
-SDL_framerate: framerate manager
+SDL_framerate.h: framerate manager
 
-LGPL (c) A. Schiffler
+Copyright (C) 2001-2011  Andreas Schiffler
+
+This software is provided 'as-is', without any express or implied
+warranty. In no event will the authors be held liable for any damages
+arising from the use of this software.
+
+Permission is granted to anyone to use this software for any purpose,
+including commercial applications, and to alter it and redistribute it
+freely, subject to the following restrictions:
+
+   1. The origin of this software must not be misrepresented; you must not
+   claim that you wrote the original software. If you use this software
+   in a product, an acknowledgment in the product documentation would be
+   appreciated but is not required.
+
+   2. Altered source versions must be plainly marked as such, and must not be
+   misrepresented as being the original software.
+
+   3. This notice may not be removed or altered from any source
+   distribution.
+
+Andreas Schiffler -- aschiffler at ferzkopp dot net
 
 */
 
@@ -48,7 +68,7 @@ extern "C" {
 
 	/* ---- Function Prototypes */
 
-#if defined(WIN32) || defined(WIN64)
+#ifdef _MSC_VER
 #  if defined(DLL_EXPORT) && !defined(LIBSDL_GFX_DLL_IMPORT)
 #    define SDL_FRAMERATE_SCOPE __declspec(dllexport)
 #  else
@@ -64,7 +84,7 @@ extern "C" {
 	/* Functions return 0 or value for sucess and -1 for error */
 
 	SDL_FRAMERATE_SCOPE void SDL_initFramerate(FPSmanager * manager);
-	SDL_FRAMERATE_SCOPE int SDL_setFramerate(FPSmanager * manager, int rate);
+	SDL_FRAMERATE_SCOPE int SDL_setFramerate(FPSmanager * manager, Uint32 rate);
 	SDL_FRAMERATE_SCOPE int SDL_getFramerate(FPSmanager * manager);
 	SDL_FRAMERATE_SCOPE int SDL_getFramecount(FPSmanager * manager);
 	SDL_FRAMERATE_SCOPE void SDL_framerateDelay(FPSmanager * manager);
